"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildTask = void 0;

var _path = require("path");

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _babel = require("../actions/tools/babel");

var _spinner = require("../cli/spinner");

var _copyFile = require("../cmd/copyFile");

var _createSpawnKillHandler = require("../utils/createSpawnKillHandler");

var _getWorkspacesOrderByDependencies = require("../utils/getWorkspacesOrderByDependencies");

var _hasDependency = require("../utils/hasDependency");

var _taskHook = require("../utils/taskHook");

var _buildBabelTask = require("./subTasks/buildBabelTask");

var _buildTscTask = require("./subTasks/buildTscTask");

const buildTask = async (argv, {
  watch
}) => {
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const hasTypescript = await (0, _hasDependency.hasDependency)(argv, {
    dependency: 'typescript',
    dependencyType: 'devDependencies'
  });
  const paths = workspacePaths.length > 0 ? workspacePaths : [argv.cwd];
  const sortedPaths = await (0, _getWorkspacesOrderByDependencies.getWorkspacesOrderByDependencies)({
    argv,
    workspacePaths: paths
  });
  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'pre'
  });

  if (watch) {
    if (workspacePaths.length === 0) {
      throw new TypeError('The watch mode is only available in a monorepo, use "npx carna start -w" instead');
    }

    const spawnKillHandler = (0, _createSpawnKillHandler.createSpawnKillHandler)({
      registerStdin: true
    });
    const promises = sortedPaths.map(async path => (0, _babel.babelAction)({ ...argv,
      cwd: path
    }, {
      watch: true,
      spawnKillHandler
    }));
    await (0, _spinner.spinnerAction)(Promise.all(promises), 'Watch-Mode - exit with "ctrl-c"');
  } else {
    if (hasTypescript) {
      await sortedPaths.reduce(async (promise, path) => promise.then((0, _buildTscTask.buildTscTask)({
        argv,
        path
      })), Promise.resolve());
    }

    await sortedPaths.reduce(async (promise, path) => promise.then((0, _buildBabelTask.buildBabelTask)({
      argv,
      path
    })), Promise.resolve());
    await Promise.all(workspacePaths.map(async workspacePath => (0, _copyFile.copyFile)({
      src: (0, _path.join)(argv.root, '.npmignore'),
      dest: (0, _path.join)(workspacePath, '.npmignore')
    })));
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'post'
  });
};

exports.buildTask = buildTask;