"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAnalyseFiles = void 0;

var _path = require("path");

var _util = require("util");

var _tools = require("@kettil/tools");

var _glob = require("glob");

var _ls = require("../actions/git/ls");

var _staged = require("../actions/git/staged");

var _access = require("../cmd/access");

var _existFiles = require("../cmd/existFiles");

var _cleanAnalyseFiles = require("./cleanAnalyseFiles");

const globPromise = (0, _util.promisify)(_glob.glob);

const getAnalyseFiles = async (argv, {
  files,
  all,
  path
}) => {
  if (all || files) {
    return files;
  }

  if ((0, _tools.isString)(path)) {
    const pathFiles = await globPromise(`${path}/**/*`, {
      cwd: argv.cwd,
      absolute: true
    });
    return (0, _cleanAnalyseFiles.cleanAnalyseFiles)(pathFiles);
  }

  const hasGitFolder = await (0, _access.access)((0, _path.join)(argv.root, '.git'), 'readable');

  if (!hasGitFolder) {
    return undefined;
  }

  const [changedFiles, stagedFiles] = await Promise.all([(0, _ls.gitLsAction)(argv, {
    mode: 'all'
  }), (0, _staged.gitStagedAction)(argv, {})]);
  const changedAndExistFiles = await (0, _existFiles.existFiles)((0, _tools.uniqueArray)([...changedFiles, ...stagedFiles]), argv.root);
  return (0, _cleanAnalyseFiles.cleanAnalyseFiles)(changedAndExistFiles);
};

exports.getAnalyseFiles = getAnalyseFiles;